#!/bin/sh
# ircmap_create.sh v0.95
#
# Copyright 2002 Julien Wajsberg <flash@rezosup.net>
#
# This file is part of IRCmap4rz.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
# By Flash <flash@rezosup.net>
# For RezoSup
#
# 2002, 11th mars - version 0.9 : complete rewriting
# 2002, 19th mars - version 0.91 : minor bugfixes
# 2002, 25th may  - version 0.92 : made the workspace bigger
# 2002, 24th june - version 0.93 : removes the temporary files on exit
# 2003, 16th May  - version 0.95 : generates a thumbnail

# configuration
CACHEDIR=/var/cache/ircmap

# temp file
file=`mktemp /tmp/ircmap.XXXXXX`
ppmfile=`mktemp -u /tmp/ircmap.XXXXXX`
linksgetdump=`mktemp /tmp/ircmap.XXXXXX`

# defaults
port=6667
password=
force=false
error=false

# init
dirname=`dirname $0`
scriptname=`basename $0`
LINKSGET=${dirname}/linksget
IRCMAP_CONVERT=${dirname}/ircmap_convert.pl

# parse arguments
while getopts s:p:P:n:o:t:f arg ; do
	case "${arg}" in
		s)
			server=${OPTARG}
			;;
		P)
			port=${OPTARG}
			;;
		p)
			password=${OPTARG}
			;;
		n)
			network=${OPTARG}
			;;
		o)
			output=${OPTARG}
			;;
		f)
			force=true
			;;
		t)
			thumb=${OPTARG}
			;;
		*)
			error=true
	esac
done

if ${error} || [ -z "${server}" -o -z "${network}" ] ; then
	echo "Error : not enough arguments"
	echo "Usage : ${scriptname} -s <server> [ -p <password> ] [ -P <port> ] -o <output_image> -n <network> [ -f ]"
	exit -1
fi

if [ ! -d ${CACHEDIR} -o ! -w ${CACHEDIR} ] ; then
	echo "Error : cache directory ${CACHEDIR} doesn't exist or isn't writable."
	exit -2
fi

if [ ! -x `which aisee` ] ; then
	echo "Error : aiSee either not found or not executable.";
	exit -3
fi

echo "Getting links on IRC server..."
${LINKSGET} ${server} ${port} ${password} | egrep -v '^:[^ ]+ 364 [^ ]+ ([^ ]+) (\1)' > ${linksgetdump}

if ! ${force} ; then
	echo "Comparing with cache..."
	if ! ${force} && cmp -s ${linksgetdump} ${CACHEDIR}/linksget-${network}.cache ; then
		echo "No changes in links."
		rm -f ${linksgetdump} ${file} ${ppmfile}
		exit 1
	fi
fi

mv -f ${linksgetdump} ${CACHEDIR}/linksget-${network}.cache

echo "Converting to aisee format..."
${IRCMAP_CONVERT} < ${CACHEDIR}/linksget-${network}.cache > ${file}

echo "Generating ppm image with aiSee :"
aisee -ppmoutput ${ppmfile} -xdpi 200 -ydpi 200 -paper tabloid -scale 100% ${file}

echo
echo "Converting to ${output} using ImageMagick..."
date=`date`
convert -crop 0x0 -bordercolor black -border 1x1 -font helvetica -fill black -draw "text 5,-15 \"${date}\"" ${ppmfile} ${output}

if [ -n "$thumb" ] ; then
  echo "Generating thumbnail ${thumb} using ImageMagick..."
  convert -geometry '640>' ${output} ${thumb}
fi

# nettoyage
rm -f ${ppmfile} ${file}

echo "Done."


